Voting
======

Information
-----------
Name:
  ``pyplanet.apps.contrib.voting``
Depends on:
  ``core.maniaplanet``
Game:
  Trackmania, Trackmania Next, Shootmania

Features
--------
This app provides chat-based voting for your players.

Commands
--------

Replay Vote
~~~~~~~~~~~
Command:
  ``/replay``
Parameters:
  None.
Functionality:
  Initiate replay vote.
Required permission:
  None.

Skip Vote
~~~~~~~~~
Command:
  ``/skip``
Parameters:
  None.
Functionality:
  Initiate skip vote.
Required permission:
  None.

Restart Vote
~~~~~~~~~~~~
Command:
  ``/restart``
Parameters:
  None.
Functionality:
  Initiate instant-restart vote.
Required permission:
  None.

Extend TimeAttack Time
~~~~~~~~~~~~~~~~~~~~~~
Command:
  ``/extend``
Parameters:
  None.
Functionality:
  Initiate time extend vote.
Required permission:
  None.

Vote Yes
~~~~~~~~
Command:
  ``/y``
Parameters:
  None.
Functionality:
  Vote yes, you can also use F5 to vote yes.
Required permission:
  None.

Vote No
~~~~~~~
Command:
  ``/n``
Parameters:
  None.
Functionality:
  Vote no, you can also use F6 to vote no.
Required permission:
  None.

Cancel Vote
~~~~~~~~~~~
Command:
  ``//cancel``
Parameters:
  None.
Functionality:
  Cancel current chat-based vote.
Required permission:
  ``voting:cancel``, requires admin level 1.

Signal handlers
---------------
None.
